@@ -6,25 +6,21 @@ from pydantic import BaseModel, Field
 
 
 class CovidModel(BaseModel):
-    """Dataclass acts as a Model for Covid data
-
-    """
+    """Dataclass acts as a Model for Covid data"""
 
     id: str = Field(..., alias="OBJECTID")
     country: str = Field(..., alias="Country_Region")
-    confirmed: int = Field(0, alias="Confirmed")
-    active: int = Field(0, alias="Active")
-    deaths: int = Field(0, alias="Deaths")
+    confirmed: int = Field(None, alias="Confirmed")
+    active: int = Field(None, alias="Active")
+    deaths: int = Field(None, alias="Deaths")
     recovered: int = Field(None, alias="Recovered")
     latitude: float = Field(None, alias="Lat")
     longitude: float = Field(None, alias="Long_")
-    last_update: int = Field(0, alias="Last_Update")
+    last_update: int = Field(None, alias="Last_Update")
 
 
 class CountryModel(BaseModel):
-    """Dataclass acts as a Model for Countries data
-
-    """
+    """Dataclass acts as a Model for Countries data"""
 
     id: str = Field(..., alias="OBJECTID")
     name: str = Field(..., alias="Country_Region")
